@@ -13,10 +13,10 @@ def get_alibaba_2018_trace(trace="machine_usage", day=None, stride_seconds=10, f
     assert format in ['dataframe', 'ndarray'], 'only "dataframe" and "ndarray" are supported right now'
     if (day is None):
         contents = pkg_resources.read_text(alibaba2018, f'{trace}_days_1_to_8_grouped_{stride_seconds}_seconds.csv')
-        res = pd.read_csv(StringIO(contents))
+        res = pd.read_csv(StringIO(contents), index=False)
     else:
         contents = pkg_resources.read_text(alibaba2018, f'{trace}_day_{day}_grouped_{stride_seconds}_seconds.csv')
-        res = pd.read_csv(StringIO(contents))
+        res = pd.read_csv(StringIO(contents), index=False)
     if format == 'ndarray':
         res = res.to_numpy()
     return res
\ No newline at end of file
